@@ -137,4 +137,8 @@ vfplot <- function( vf, plotType,
              xmin = xmin, xmax = xmax, ymin = ymin, ymax = ymax,
              txtfont = txtfont, pointsize = pointsize,
              showaxis = showaxis, colaxis = colaxis )
+  # add horizontal and vertical midlines
+  axis( 1, pos = 0, labels = FALSE, lwd.ticks = 0, at = c( xmin, xmax ), col = "black" )
+  axis( 2, pos = 0, labels = FALSE, lwd.ticks = 0, at = c( ymin, ymax ), col = "black" )
+  
 }
\ No newline at end of file
